/*******************************************************************************
 *
 *                                 Silverjuke
 *     Copyright (C) 2015 Björn Petersen Software Design and Development
 *                   Contact: r10s@b44t.com, http://b44t.com
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program.  If not, see http://www.gnu.org/licenses/ .
 *
 *******************************************************************************
 *
 * File:    typessj.h
 * Authors: Björn Petersen
 * Purpose: Some common type definitins
 *
 ******************************************************************************/



#ifndef __SJ_TYPES_H__
#define __SJ_TYPES_H__



#ifdef __cplusplus
extern "C" {
#endif



#define SjUint uint32_t // needed for tagger, _must_ be 32 bit, for future use, we should prefer using uint32_t etc. directly



#ifdef __cplusplus
};
#endif



#endif /* __SJ_TYPES_H__ */
